.\"
.\" @(#)$GW: cronrun/cronrun.man,v 1.11 2015/05/26 19:36:27 kim Exp $
.\"
.\" Copyright (c) 2000-2015 Kimmo Suominen
.\" All rights reserved.
.\"
.\" Redistribution and use in source and binary forms, with or without
.\" modification, are permitted provided that the following conditions
.\" are met:
.\" 1. Redistributions of source code must retain the above copyright
.\"    notice, this list of conditions and the following disclaimer.
.\" 2. Redistributions in binary form must reproduce the above copyright
.\"    notice, this list of conditions and the following disclaimer in the
.\"    documentation and/or other materials provided with the distribution.
.\"
.\" THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS
.\" OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
.\" WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
.\" ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY
.\" DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
.\" DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE
.\" GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
.\" INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER
.\" IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
.\" OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN
.\" IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
.\"
.Dd January 25, 2012
.Dt CRONRUN 1
.Os
.Sh NAME
.Nm cronrun
.Nd run a command and report on its results
.Sh SYNOPSIS
.Nm
.Aq options
.Ar command
.Op Ar args ...
.Nm
.Ar subject
.Ar recipients
.Ar command
.Op Ar args ...
.Sh DESCRIPTION
The
.Nm
command captures any output from
.Ar command
and either sends it via mail or posts a status to Nagios, or both.
.Pp
The second form is deprecated. Please migrate to using the
.Fl m ,
.Fl s
and
.Fl t
options instead.
.Ss Mail mode
In mail mode
.Nm
combines stdout and stderr output from
.Ar command
and mails it to the specified recipients.
.Pp
.Bl -tag -width "-e errorsto" -compact
.It Fl m
Enable mail mode.
.It Fl t Ar to
Recipients (primary recipients).
.It Fl e Ar errorsto
Recipients for a failed run: one that exits non-zero.
.It Fl c Ar cc
Carbon copy (visible additional recipients).
.It Fl b Ar bcc
Blind carbon copy (invisible additional recipients).
.It Fl f Ar from
Sender.
.It Fl s Ar subject
Subject.
.It Fl C Ar charset
Encode the message and label with the given character set.
.It Fl T
Prepend hostname to subject (tag; see also -H).
.El
.Pp
If no recipients are given,
.Nm
will use the value of the
.Va USER
environment variable (or if unset, the
.Va LOGNAME
variable) as the
.Ar bcc
list.
.Pp
If no sender is given,
.Ar from
will be set using the same logic as described for the
.Ar bcc
list above.
.Pp
The
.Ar subject
defaults to
.Dq hostname : Ar command
for successful runs. It will be prefixed with
.Dq FAILED -
if the run fails.
.Pp
Specifying a
.Ar charset
results in the message being encoded in quoted-printable and
labeled with the
.Ar charset .
If
.Dq us-ascii
(the default value) is used, no encoding is applied.
.Pp
Note that any arguments that contain whitespace (or other special
characters) need to be quoted. This is often the case with the
.Ar subject
and the recipient lists
.Ar ( to , errorsto , cc
and
.Ar bcc )
as well as the sender
.Ar ( from ) .
.Pp
Multiple recipients can be specified as a comma separated list
or by repeating the recipient list option.
.Pp
If
.Ar command
terminates with a non-zero exit code,  the message will be marked
as high importance.
.Ss Report mode
Report mode is similar to mail mode, except that
.Nm
will keep output to stdout and stderr separate.  If there is any
output to stderr, the run is considered failed, even if
.Ar command
exits with a zero exit code.
.Pp
This behavior is useful when you don't want errors (and possibly
unwanted output or results) sent to the normal audience of successful
runs.
.Pp
.Bl -tag -width "-e errorsto" -compact
.It Fl r
Enable report mode.
.El
.Pp
All the mail mode options are effective in report mode as well. Report
mode takes precedence over mail mode, if both are selected.
.Ss Nagios mode
In Nagios mode
.Nm
will send a notification to Nagios using the NSCA protocol. The status
sent is based on the exit code from
.Ar command ,
and its first line of output is sent as additional information.
.Pp
If report mode has also been selected, the first line of stderr is sent.
If there was no output to stderr, the first line of stdout is sent.
.Pp
.Bl -tag -width "-e errorsto" -compact
.It Fl n
Enable Nagios mode.
.It Fl H Ar host
Host to use in status message.
.It Fl S Ar service
Service to use in status message.
.It Fl N Ar servers
Nagios server hosts (receivers of NSCA messages). Multiple servers can
be given as a space or comma delimited list.
.It Fl P Ar port
NSCA service port number.
.El
.Pp
The
.Ar host
defaults to the host where
.Nm
is being run. The
.Ar service
defaults to
.Ar command .
.Pp
The
.Ar server
defaults to
.Dq nagios
and the
.Ar port
to
.Dq 5667 .
.Pp
Typically the
.Ar server
and
.Ar port
are set in the configuration file, overriding the defaults documented
here. Use the
.Fl d
option to see the values for your installation.
.Ss General options
These options affect all operating modes.
.Pp
.Bl -tag -width "MMM"
.It Fl d
Dump configuration, do not run anything (debug).
.It Fl p Ar logdir
Path to the log directory. If mail or report mode is enabled,
the default is
.Pa /tmp
or the value of
.Va TMPDIR .
The log files will be removed after mailing the results.
If only Nagios mode is used, the log files will be placed in
.Pa /var/log/cronrun
and left in place. You should arrange for old log files to be
removed periodically.
.It Fl q
Silence some error messages (quiet). This is the default when
.Nm
is invoked not connected to a terminal, typically by cron. It silences
errors that are expected at times but not wanted through mail from cron,
such as failures to contact the Nagios server.
.It Fl v
Output all status information on stdout only (verbose). Nothing will be
mailed or posted to Nagios.
.It Fl w Ar maxwait
Wait up to
.Ar maxwait
seconds before running
.Ar command .
Typically this is used to avoid the
.Dq thundering herd
problem of many machines running something at exactly the same time,
possibly overwhelming some shared resource.
.El
.Sh FILES
.Bl -tag -width "MMM"
.It Pa /etc/cronrun.conf
This is the configuration file for
.Nm .
It is sourced, so it can contain complex conditions. Typically it is used
to set defaults, e.g. the Nagios server host and its NSCA service port.
.It Pa /var/log/cronrun
This is the
.Ar logdir
when run in Nagios mode only and log files will accumulate here.
.It Pa /tmp
This is the
.Ar logdir
when run in mail or report mode and log files will be deleted after mailing.
.El
.Sh AUTHOR
.An Kimmo Suominen
